# quangpy: Python package for Quantitative Genetics Analysis

## Overview

`quangpy` mainly provides Joint Scale Analysis and Variance Decomposition Analysis.

## Installation

```bash
pip install quangpy
```
